@@ -1,23 +1,8 @@
 /*
- * This file is part of KSysGuard.
- * Copyright 2019 Arjen Hiemstra <ahiemstra@heimr.nl>
- * 
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2019 Arjen Hiemstra <ahiemstra@heimr.nl>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #ifndef KSYSGUARD_PROCESSCONTROLLER_H
 #define KSYSGUARD_PROCESSCONTROLLER_H
@@ -41,14 +26,14 @@ class QWidget;
  * processes directly, if that fails, it will use KAuth to try and perform the
  * action as root.
  */
-namespace KSysGuard {
-
+namespace KSysGuard
+{
 class Q_DECL_EXPORT ProcessController : public QObject
 {
     Q_OBJECT
 
 public:
-    ProcessController(QObject* parent = nullptr);
+    ProcessController(QObject *parent = nullptr);
     ~ProcessController();
 
     /**
